.. py:function:: complex_negative(a [, ret])

    Wrapper for :c:func:`gsl_complex_negative`
    c code signature: gsl_complex gsl_complex_negative( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_log10(a [, ret])

    Wrapper for :c:func:`gsl_complex_log10`
    c code signature: gsl_complex gsl_complex_log10( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arctanh_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arctanh_real`
    c code signature: gsl_complex gsl_complex_arctanh_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_add_real(a, x [, ret])

    Wrapper for :c:func:`gsl_complex_add_real`
    c code signature: gsl_complex gsl_complex_add_real( gsl_complex a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double x: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_exp(a [, ret])

    Wrapper for :c:func:`gsl_complex_exp`
    c code signature: gsl_complex gsl_complex_exp( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_log_b(a, b [, ret])

    Wrapper for :c:func:`gsl_complex_log_b`
    c code signature: gsl_complex gsl_complex_log_b( gsl_complex a,  gsl_complex b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_D__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex b: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_logabs(z [, ret])

    Wrapper for :c:func:`gsl_complex_logabs`
    c code signature: double gsl_complex_logabs( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__Rd__O`
    
    :param gsl_complex z: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: complex_polar(r, theta [, ret])

    Wrapper for :c:func:`gsl_complex_polar`
    c code signature: gsl_complex gsl_complex_polar( double r,  double theta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__RD__O`
    
    :param double r: positional argument 0
    :param double theta: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arctanh(a [, ret])

    Wrapper for :c:func:`gsl_complex_arctanh`
    c code signature: gsl_complex gsl_complex_arctanh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_abs(z [, ret])

    Wrapper for :c:func:`gsl_complex_abs`
    c code signature: double gsl_complex_abs( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__Rd__O`
    
    :param gsl_complex z: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: complex_sech(a [, ret])

    Wrapper for :c:func:`gsl_complex_sech`
    c code signature: gsl_complex gsl_complex_sech( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_div_imag(a, y [, ret])

    Wrapper for :c:func:`gsl_complex_div_imag`
    c code signature: gsl_complex gsl_complex_div_imag( gsl_complex a,  double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double y: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_cot(a [, ret])

    Wrapper for :c:func:`gsl_complex_cot`
    c code signature: gsl_complex gsl_complex_cot( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sqrt_real(x [, ret])

    Wrapper for :c:func:`gsl_complex_sqrt_real`
    c code signature: gsl_complex gsl_complex_sqrt_real( double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double x: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccsc(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccsc`
    c code signature: gsl_complex gsl_complex_arccsc( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_mul_imag(a, y [, ret])

    Wrapper for :c:func:`gsl_complex_mul_imag`
    c code signature: gsl_complex gsl_complex_mul_imag( gsl_complex a,  double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double y: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arctan(a [, ret])

    Wrapper for :c:func:`gsl_complex_arctan`
    c code signature: gsl_complex gsl_complex_arctan( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_tanh(a [, ret])

    Wrapper for :c:func:`gsl_complex_tanh`
    c code signature: gsl_complex gsl_complex_tanh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sin(a [, ret])

    Wrapper for :c:func:`gsl_complex_sin`
    c code signature: gsl_complex gsl_complex_sin( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsin_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsin_real`
    c code signature: gsl_complex gsl_complex_arcsin_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sub_real(a, x [, ret])

    Wrapper for :c:func:`gsl_complex_sub_real`
    c code signature: gsl_complex gsl_complex_sub_real( gsl_complex a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double x: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_cosh(a [, ret])

    Wrapper for :c:func:`gsl_complex_cosh`
    c code signature: gsl_complex gsl_complex_cosh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccos_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccos_real`
    c code signature: gsl_complex gsl_complex_arccos_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsinh(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsinh`
    c code signature: gsl_complex gsl_complex_arcsinh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_log(a [, ret])

    Wrapper for :c:func:`gsl_complex_log`
    c code signature: gsl_complex gsl_complex_log( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_csc(a [, ret])

    Wrapper for :c:func:`gsl_complex_csc`
    c code signature: gsl_complex gsl_complex_csc( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_mul_real(a, x [, ret])

    Wrapper for :c:func:`gsl_complex_mul_real`
    c code signature: gsl_complex gsl_complex_mul_real( gsl_complex a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double x: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_inverse(a [, ret])

    Wrapper for :c:func:`gsl_complex_inverse`
    c code signature: gsl_complex gsl_complex_inverse( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccosh_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccosh_real`
    c code signature: gsl_complex gsl_complex_arccosh_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_div(a, b [, ret])

    Wrapper for :c:func:`gsl_complex_div`
    c code signature: gsl_complex gsl_complex_div( gsl_complex a,  gsl_complex b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_D__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex b: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sinh(a [, ret])

    Wrapper for :c:func:`gsl_complex_sinh`
    c code signature: gsl_complex gsl_complex_sinh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_csch(a [, ret])

    Wrapper for :c:func:`gsl_complex_csch`
    c code signature: gsl_complex gsl_complex_csch( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsech(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsech`
    c code signature: gsl_complex gsl_complex_arcsech( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_mul(a, b [, ret])

    Wrapper for :c:func:`gsl_complex_mul`
    c code signature: gsl_complex gsl_complex_mul( gsl_complex a,  gsl_complex b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_D__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex b: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arg(z [, ret])

    Wrapper for :c:func:`gsl_complex_arg`
    c code signature: double gsl_complex_arg( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__Rd__O`
    
    :param gsl_complex z: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: complex_sub_imag(a, y [, ret])

    Wrapper for :c:func:`gsl_complex_sub_imag`
    c code signature: gsl_complex gsl_complex_sub_imag( gsl_complex a,  double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double y: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_add_imag(a, y [, ret])

    Wrapper for :c:func:`gsl_complex_add_imag`
    c code signature: gsl_complex gsl_complex_add_imag( gsl_complex a,  double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double y: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sqrt(z [, ret])

    Wrapper for :c:func:`gsl_complex_sqrt`
    c code signature: gsl_complex gsl_complex_sqrt( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex z: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccsch(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccsch`
    c code signature: gsl_complex gsl_complex_arccsch( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_div_real(a, x [, ret])

    Wrapper for :c:func:`gsl_complex_div_real`
    c code signature: gsl_complex gsl_complex_div_real( gsl_complex a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_d__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param double x: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_coth(a [, ret])

    Wrapper for :c:func:`gsl_complex_coth`
    c code signature: gsl_complex gsl_complex_coth( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsin(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsin`
    c code signature: gsl_complex gsl_complex_arcsin( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_add(a, b [, ret])

    Wrapper for :c:func:`gsl_complex_add`
    c code signature: gsl_complex gsl_complex_add( gsl_complex a,  gsl_complex b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_D__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex b: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sub(a, b [, ret])

    Wrapper for :c:func:`gsl_complex_sub`
    c code signature: gsl_complex gsl_complex_sub( gsl_complex a,  gsl_complex b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID_D__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex b: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_sec(a [, ret])

    Wrapper for :c:func:`gsl_complex_sec`
    c code signature: gsl_complex gsl_complex_sec( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccos(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccos`
    c code signature: gsl_complex gsl_complex_arccos( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_tan(a [, ret])

    Wrapper for :c:func:`gsl_complex_tan`
    c code signature: gsl_complex gsl_complex_tan( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_conjugate(z [, ret])

    Wrapper for :c:func:`gsl_complex_conjugate`
    c code signature: gsl_complex gsl_complex_conjugate( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex z: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccsc_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccsc_real`
    c code signature: gsl_complex gsl_complex_arccsc_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccoth(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccoth`
    c code signature: gsl_complex gsl_complex_arccoth( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsec(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsec`
    c code signature: gsl_complex gsl_complex_arcsec( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccosh(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccosh`
    c code signature: gsl_complex gsl_complex_arccosh( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_rect(x, y [, ret])

    Wrapper for :c:func:`gsl_complex_rect`
    c code signature: gsl_complex gsl_complex_rect( double x,  double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__RD__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param gsl_complex ret: positional argument 2
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arcsec_real(a [, ret])

    Wrapper for :c:func:`gsl_complex_arcsec_real`
    c code signature: gsl_complex gsl_complex_arcsec_real( double a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__RD__O`
    
    :param double a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_cos(a [, ret])

    Wrapper for :c:func:`gsl_complex_cos`
    c code signature: gsl_complex gsl_complex_cos( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_arccot(a [, ret])

    Wrapper for :c:func:`gsl_complex_arccot`
    c code signature: gsl_complex gsl_complex_arccot( gsl_complex a)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__RD__O`
    
    :param gsl_complex a: positional argument 0
    :param gsl_complex ret: positional argument 1
    :rtype:  gsl_complex 
    :return: result 

.. py:function:: complex_abs2(z [, ret])

    Wrapper for :c:func:`gsl_complex_abs2`
    c code signature: double gsl_complex_abs2( gsl_complex z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_ID__Rd__O`
    
    :param gsl_complex z: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

